@@ -9,12 +9,11 @@ import RDFMessage.Store
 
 args = {
     "store" : "testdb",
-    "store-type" : "sqltriples",
     "module" : "PgSQL",
     "base" : "/"
     }
 
-_store, _impl = RDFFormats.Store.open(args["store"], args.get("store-type", "sqltriples"), database_module_name=args.get("module"),
+_store, _impl = RDFFormats.Store.open(args["store"], "sqltriples", database_module_name=args["module"],
     debug=args.has_key("debug"))
 cstore = RDFCalendar.Store.Store(_store, _impl)
 mstore = RDFMessage.Store.Store(_store, _impl)
