@@ -14,6 +14,9 @@ cwd = os.path.split(program)[0]
 
 # Set up the environment and obtain the application resource.
 
+weborganiser = os.path.join(cwd, "WebOrganiser")
+if os.path.exists(weborganiser):
+    sys.path.insert(0, cwd)
 applications = os.path.join(cwd, "applications")
 if os.path.exists(applications):
     sys.path.insert(0, applications)
